@@ -237,7 +237,8 @@ class Broadcast:
                         elif log[0] is TrackLogType.LookupEnd:
                             current_path = None
                         elif (
-                            log[0] is TrackLogType.Result
+                            current_path is not None
+                            and log[0] is TrackLogType.Result
                             and log[2] not in current_path_set
                         ):
                             current_path[0].append(log[2])
@@ -247,8 +248,6 @@ class Broadcast:
 
                     target.maybe_failure.symmetric_difference_update(has_failures)
 
-                
-
             if result.__class__ is Force:
                 return result.content
 
